@@ -38,7 +38,11 @@ from robotoff.insights.extraction import (
     extract_ocr_predictions,
 )
 from robotoff.insights.question import QuestionFormatter, QuestionFormatterFactory
-from robotoff.logos import generate_insights_from_annotated_logos, knn_search
+from robotoff.logos import (
+    generate_insights_from_annotated_logos,
+    generate_insights_from_annotated_logos_job,
+    knn_search,
+)
 from robotoff.models import (
     ImageModel,
     ImagePrediction,
@@ -474,7 +478,7 @@ class ImageImporterResource:
         ocr_url = req.get_param("ocr_url", required=True)
         server_domain = req.get_param("server_domain", required=True)
 
-        if server_domain != settings.OFF_SERVER_DOMAIN:
+        if server_domain != settings.BaseURLProvider.server_domain():
             logger.info("Rejecting image import from %s", server_domain)
             resp.media = {
                 "status": "rejected",
@@ -525,7 +529,7 @@ class ImagePredictionImporterResource:
 
         for prediction in req.media["predictions"]:
             server_domain: str = prediction.get(
-                "server_domain", settings.OFF_SERVER_DOMAIN
+                "server_domain", settings.BaseURLProvider.server_domain()
             )
             server_type: str = get_server_type(server_domain).name
             source_image = generate_image_path(
@@ -798,7 +802,7 @@ class ImageLogoDetailResource:
                     completed_at=datetime.datetime.utcnow(),
                 )
                 generate_insights_from_annotated_logos(
-                    annotated_logos, settings.OFF_SERVER_DOMAIN, auth
+                    annotated_logos, settings.BaseURLProvider.server_domain(), auth
                 )
 
         resp.status = falcon.HTTP_204
@@ -862,7 +866,9 @@ class ImageLogoAnnotateResource:
             raise falcon.HTTPForbidden(
                 description="authentication is required to annotate logos"
             )
-        server_domain = req.media.get("server_domain", settings.OFF_SERVER_DOMAIN)
+        server_domain = req.media.get(
+            "server_domain", settings.BaseURLProvider.server_domain()
+        )
         annotations = req.media["annotations"]
         completed_at = datetime.datetime.utcnow()
         annotation_logos = []
@@ -889,12 +895,17 @@ class ImageLogoAnnotateResource:
                     username=auth.get_username() or "unknown",
                     completed_at=completed_at,
                 )
-                annotated = generate_insights_from_annotated_logos(
-                    annotated_logos, server_domain, auth
-                )
-            else:
-                annotated = 0
-        resp.media = {"created insights": annotated}
+
+        logo_ids = [logo.id for logo in annotated_logos]
+        enqueue_job(
+            generate_insights_from_annotated_logos_job,
+            high_queue,
+            {"result_ttl": 0, "timeout": "5m"},
+            logo_ids=logo_ids,
+            server_domain=server_domain,
+            auth=auth,
+        )
+        resp.media = {"annotated": len(annotated_logos)}
 
 
 class ImageLogoUpdateResource:
@@ -983,7 +994,7 @@ class WebhookProductResource:
         barcode = req.get_param("barcode", required=True)
         action = req.get_param("action", required=True)
         server_domain = req.get_param("server_domain", required=True)
-        if server_domain != settings.OFF_SERVER_DOMAIN:
+        if server_domain != settings.BaseURLProvider.server_domain():
             logger.info("Rejecting webhook event from {}".format(server_domain))
             resp.media = {
                 "status": "rejected",
@@ -1248,7 +1259,7 @@ class ImageCollection:
             "with_predictions", default=False
         )
         barcode: Optional[str] = req.get_param("barcode")
-        server_domain = settings.OFF_SERVER_DOMAIN
+        server_domain = settings.BaseURLProvider.server_domain()
 
         get_images_ = functools.partial(
             get_images,
